/// <reference types="node" />
import { EventEmitter } from 'events';
import { Tracer } from 'opentracing';
import { Message, MessageWriter } from 'vscode-jsonrpc';
import { Logger } from './logging';
import { TypeScriptService } from './typescript-service';
/**
 * Takes a NodeJS ReadableStream and emits parsed messages received on the stream.
 * In opposite to StreamMessageReader, supports multiple listeners and is compatible with Observables
 */
export declare class MessageEmitter extends EventEmitter {
    constructor(input: NodeJS.ReadableStream);
    on(event: 'message', listener: (message: Message) => void): this;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'close', listener: () => void): this;
    once(event: 'message', listener: (message: Message) => void): this;
    once(event: 'error', listener: (error: Error) => void): this;
    once(event: 'close', listener: () => void): this;
}
export interface RegisterLanguageHandlerOptions {
    /** A logger that all messages will be logged to */
    logger?: Logger;
    /** An opentracing-compatible tracer */
    tracer?: Tracer;
    /** Whether to log all messages */
    logMessages?: boolean;
}
/**
 * Registers all method implementations of a LanguageHandler on a connection
 *
 * @param messageEmitter MessageEmitter to listen on
 * @param messageWriter MessageWriter to write to
 * @param handler TypeScriptService object that contains methods for all methods to be handled
 */
export declare function registerLanguageHandler(messageEmitter: MessageEmitter, messageWriter: MessageWriter, handler: TypeScriptService, options?: RegisterLanguageHandlerOptions): void;
